@@ -1,9 +1,9 @@
 /*
- * AnthyΥμդץꥨǥåȤԤ쥤䡼
+ * Anthyのキーの受け付けやプリエディットの制御を行うレイヤー
  *
- * 饢ץꥱ񤯾ˤuimѤᤷޤ
+ * 今からアプリケーションを書く場合にはuimの利用をお薦めします。
  *
- * Funded by IPA̤Ƨեȥ¤ 2002 1/23
+ * Funded by IPA未踏ソフトウェア創造事業 2002 1/23
  * Copyright (C) 2001-2002 UGAWA Tomoharu
  *
  */
@@ -30,7 +30,7 @@ struct anthy_input_context {
   /* always allocated */
   struct rk_conv_context* rkctx;
   int map_no;  /* RKMAP_* */
-  /* ѴʸΥХåե*/
+  /* 変換する文字列のバッファ*/
   char* hbuf;
   int n_hbuf;
   int s_hbuf;
@@ -48,13 +48,13 @@ struct anthy_input_context {
   int last_gotten_cand;
 
   /* always allocated by the library */
-  /* ߥåȥХåե */
+  /* コミットバッファ */
   char* commit;
   int n_commit;
   int s_commit;
 
   /* always allocated by the library */
-  /* åȥХåե */
+  /* カットバッファ */
   char* cut;
   int n_cut;
   int s_cut;
@@ -74,7 +74,7 @@ int anthy_input_errno;
 
 struct anthy_input_config {
   struct rk_option* rk_option;
-  /* 6src-util/rkhelper.h  NR_RKMAP */
+  /* 6はsrc-util/rkhelper.h の NR_RKMAPに相当 */
   struct rk_map*   rk_map[6];
   struct anthy_input_context* owners;
   /**/
@@ -460,7 +460,7 @@ cmd_backspace(struct anthy_input_context* ictx)
   len = rk_get_pending_str(ictx->rkctx, NULL, 0);
   if (len > 1) {
     char* buf;
-    /* ꤵƤʤ޻ΤǡǸʸ򥫥å */
+    /* 確定されていないローマ字があるので、最後の文字をカット */
     len--;
 
     buf = (char*) malloc(len);
@@ -564,7 +564,7 @@ cmd_resize(struct anthy_input_context* ictx, int d)
   }
   ictx->last_gotten_cand = NTH_UNCONVERTED_CANDIDATE;
 
-  as = as->next;            /* ʥꥢν */
+  as = as->next;            /* 不正なメモリアクセスの修正 */
   if (as) {
     as->prev->next = NULL;
     for (; as; ) {
@@ -700,7 +700,7 @@ cmd_move_to_bol(struct anthy_input_context* ictx)
 {
   terminate_rk(ictx);
 
-  if (ictx->hbuf_follow == NULL) { /* Ŭ */
+  if (ictx->hbuf_follow == NULL) { /* 最適化 */
     ictx->hbuf_follow = ictx->hbuf;
     ictx->n_hbuf_follow = ictx->n_hbuf;
     ictx->s_hbuf_follow = ictx->s_hbuf;
@@ -724,7 +724,7 @@ cmd_move_to_eol(struct anthy_input_context* ictx)
 {
   terminate_rk(ictx);
 
-  if (ictx->hbuf == NULL) { /* Ŭ */
+  if (ictx->hbuf == NULL) { /* 最適化 */
     ictx->hbuf = ictx->hbuf_follow;
     ictx->n_hbuf = ictx->n_hbuf_follow;
     ictx->s_hbuf = ictx->s_hbuf_follow;
@@ -749,7 +749,7 @@ cmd_cut(struct anthy_input_context* ictx)
 
   terminate_rk(ictx);
 
-  /* Хåե촹ǺѤޤ */
+  /* バッファの入れ換えで済ませる */
   tmp_str = ictx->cut;
   tmp_int = ictx->s_cut;
   ictx->cut = ictx->hbuf_follow;
@@ -788,8 +788,8 @@ anthy_input_create_context(struct anthy_input_config* cfg)
   ictx->actx = NULL;
   ictx->segment = NULL;
   ictx->cur_segment = NULL;
-  ictx->enum_reverse = 0;       /* ˺ν */
-  ictx->last_gotten_cand = 0;   /* ˺ν */
+  ictx->enum_reverse = 0;       /* 初期化忘れの修正 */
+  ictx->last_gotten_cand = 0;   /* 初期化忘れの修正 */
   ictx->commit = NULL;
   ictx->n_commit = 0;
   ictx->s_commit = 0;
@@ -1197,7 +1197,7 @@ get_edit_mode_preedit(struct anthy_input_context* ictx,
 {
   struct anthy_input_segment** p;
   int len;
-  /* ʸpending||ʸ */
+  /* 左の文字列pending|カーソル|右の文字列 */
 
   p = &pedit->segment;
 
@@ -1254,7 +1254,7 @@ anthy_input_get_preedit(struct anthy_input_context* ictx)
 
   pedit->state = ictx->state;
 
-  /* ̤ߥåȤʸ */
+  /* 未コミットの文字列 */
   if (ictx->n_commit > 0) {
     pedit->commit = (char*) malloc(ictx->n_commit + 1);
     memcpy(pedit->commit, ictx->commit, ictx->n_commit);
@@ -1264,7 +1264,7 @@ anthy_input_get_preedit(struct anthy_input_context* ictx)
     pedit->commit = NULL;
   }
 
-  /* åȥХåեʸ */
+  /* カットバッファの文字列 */
   if(ictx->n_cut > 0) {
     pedit->cut_buf = (char*) malloc(ictx->n_cut + 1);
     memcpy(pedit->cut_buf, ictx->cut, ictx->n_cut);
@@ -1290,7 +1290,7 @@ anthy_input_get_preedit(struct anthy_input_context* ictx)
       struct a_segment* as;
       
       for (as = ictx->segment, p = &pedit->segment; as; as = as->next) {
-	/* ʸФ */
+	/* 各文節に対して */
 	int len, noconv_len;
 	
 	noconv_len = anthy_get_segment(ictx->actx, as->index, 
@@ -1464,7 +1464,7 @@ anthy_input_change_config(struct anthy_input_config* cfg)
   cfg->rk_map[RKMAP_SHIFT_ASCII] = make_rkmap_shiftascii(cfg->rk_option);
   cfg->rk_map[RKMAP_HANKAKU_KANA] = make_rkmap_hankaku_kana(cfg->rk_option);
 
-  /* configͭ륳ƥȤ٤ƤФ */
+  /* このconfigを共有するコンテキストすべてに対して */
   for (p = cfg->owners; p; p = p->next_cfg_owner) {
     reset_anthy_input_context(p);
     rk_register_map(p->rkctx, RKMAP_HIRAGANA, cfg->rk_map[RKMAP_HIRAGANA]);
@@ -1508,7 +1508,7 @@ anthy_input_free_config(struct anthy_input_config* cfg)
 {
   int err;
 
-  /* configͭƤcontext˲ */
+  /* このconfigを共有する全てのcontextを事前に解放する事 */
   assert(!cfg->owners);
 
   rk_map_free(cfg->rk_map[RKMAP_ASCII]);
